@@ -1,9 +1,10 @@
 # labels file name and columns
-LABELS_FILENAME = "labels.csv"
+FILENAME_ANNOTATION = "labels.csv"
 COL_ID = "data_id"
 COL_DATA_PATH = "data_path"
 COL_MASK_PATH = "mask_path"
 COL_LABEL = "label"
+COL_INDEX = "INDEX"
 
 # radiomics config
 DST_CONFIG_NAME = "radiomics.yaml"
