@@ -5,7 +5,7 @@ import json
 import argparse
 import base64
 import tqdm
-import skvideo.io
+import imageio.v3 as iio
 import numpy as np
 import pandas as pd
 import cv2
@@ -16,6 +16,7 @@ import PIL.ImageDraw
 import string
 import tempfile
 import dicom2nifti
+import traceback
 
 from typing import List, Union, Tuple
 from multiprocessing import Manager, Pool
@@ -29,6 +30,10 @@ from raymics.utils import is_image, is_video, is_ndarray, is_labelme, \
     is_dicom_folder, isBase64
 from raymics.log import logger
 
+from radiomics import setVerbosity
+setVerbosity(40)
+
+
 GROUP_LEN = 100
 
 
@@ -298,7 +303,7 @@ def extract_ts(data_idx: int,
 
     def read_ts():
         mask = None
-        for frame in skvideo.io.vreader(data_path):
+        for frame in iio.imiter(data_path):
             gray = cv2.cvtColor(frame, cv2.COLOR_RGB2GRAY)
             img = sitk.GetImageFromArray(gray)
             if mask is None:
@@ -330,16 +335,15 @@ def extract_ts(data_idx: int,
                                                index_col=COL_INDEX)
 
             rel_path = os.path.relpath(result_path, result_dir)
-            result_labels_df[COL_DATA_PATH].loc[data_idx] = rel_path
+            result_labels_df.loc[data_idx, COL_DATA_PATH] = rel_path
 
             pop_unnamed(result_labels_df).to_csv(result_labels_path,
                                                  index=True,
                                                  index_label=COL_INDEX)
 
     except Exception as e:
-        logger.warning(f"Radiomics extracting error: {e}, "
-                       f"\ndata_path: {data_path}, "
-                       f"\nmask_path: {mask_path}")
+        logger.warning(traceback.format_exc())
+        logger.warning(f"Radiomics extracting error, data_path: {data_path}")
 
 
 def extract(dataset_dir: str, result_dir: str, config: Union[str, dict],
@@ -365,6 +369,11 @@ def extract(dataset_dir: str, result_dir: str, config: Union[str, dict],
 
     if not os.path.exists(result_dir):
         os.makedirs(result_dir)
+    else:
+        result_file_list = [_ for _ in os.listdir(result_dir)
+                            if not _.startswith(".") and not _.startswith("__")]
+        assert len(result_file_list) > 0, \
+            f"The result dir '{result_dir}' is not empty."
 
     result_labels_path = os.path.join(result_dir, FILENAME_ANNOTATION)
 
@@ -386,14 +395,7 @@ def extract(dataset_dir: str, result_dir: str, config: Union[str, dict],
         group_data_idxs = [dataset.data_idxs[i: i + GROUP_LEN]
                            for i in range(0, len(idxs), GROUP_LEN)]
 
-        bar = tqdm.tqdm(total=len(group_idxs))
-        if progress is None:
-            callback = lambda _: bar.update()
-        else:
-            progress.set_tqdm(bar=bar)
-            callback = progress.update
-
-        for data_idxs, idx_list in zip(group_data_idxs, group_idxs):
+        for data_idxs, idx_list in tqdm.tqdm(list(zip(group_data_idxs, group_idxs))):
             extract_non_ts(data_idxs,
                            [dataset.data_ids[_] for _ in idx_list]
                            if dataset.data_ids else None,
@@ -402,23 +404,6 @@ def extract(dataset_dir: str, result_dir: str, config: Union[str, dict],
                            result_labels_path,
                            extractor,
                            lock)
-        # TODO: run with multi-process
-        #
-        #     pool.apply_async(
-        #         func=extract_non_ts,
-        #         args=(group_data_idxs,
-        #               [dataset.data_ids[_] for _ in idx_list]
-        #               if dataset.data_ids else None,
-        #               [dataset.data_paths[_] for _ in idx_list],
-        #               [dataset.mask_paths[_] for _ in idx_list],
-        #               result_labels_path,
-        #               extractor,
-        #               lock),
-        #         callback=callback
-        #     )
-        #
-        # pool.close()
-        # pool.join()
 
         # concat original labels.csv and feature labels.csv
         labels_df = pd.read_csv(dataset.labels_file)
